==> packagesearch_2.2.5.tar.gz: packagesearch-2.2.5/src/plugins/debtagsplugin/debtagssettingswidget.cpp <==
//
// C++ Implementation: debtagssettingswidget
//
// Description: 
//
//
// Author: Benjamin Mesing <bensmail@gmx.net>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "debtagssettingswidget.h"

#if 0
// apt-front
#include <apt-front/cache/entity/tag.h>
#include <apt-front/cache/component/tags.h>
#endif
#include <wibble/operators.h>
#include <ept/configuration/apt.h>
#include <ept/cache/apt/packages.h>
#include <ept/cache/debtags/vocabulary.h>


#include <helpers.h>

#include "exception.h"
#include "eptinstance.h"

#if 0
using namespace aptFront::cache::component;
using namespace aptFront::cache::entity;
#endif

DebtagsSettingsWidget::DebtagsSettingsWidget(const set<string>& hiddenFacets, 
	QWidget *parent, const char *name)
 : QWidget(parent), Ui::DebtagsSettingsWidget()
{
	using namespace wibble::operators;
	typedef ept::configuration::apt::cache::Vocabulary Vocabulary;
	typedef ept::configuration::apt::cache::Facet Facet;

	if (name)
		setObjectName(name);
	setupUi(this);

	Vocabulary& tags = EptInstance::aggregator()->vocabulary();

	std::set<Facet> hidden;
	for (set<string>::const_iterator it = hiddenFacets.begin(); it != hiddenFacets.end(); it++)
	{
		Facet f = tags.facetByName(*it);
		if (f.valid())
			hidden |= f;
	}
	std::set<Facet> facets = tags.facets();

	// iterate over all facets
	for ( std::set<Facet>::const_iterator it = facets.begin(); it != facets.end(); ++it )
	{
		const Facet& facet = *it;
		if ( hidden.find(facet) == hidden.end() ) // if the facet is not hidden
		// worked around gcc 4.1 not compiling this for an unknown reason
		// 		if ( !hidden.contains(facet) ) // if the facet is not hidden
		{
			new Q3ListViewItem(_pShownFacetsList, toQString(facet.name()), toQString(facet.shortDescription()));
		}
		else
		{
			new Q3ListViewItem(_pHiddenFacetsList, toQString(facet.name()), toQString(facet.shortDescription()));
		}
	}


}


DebtagsSettingsWidget::~DebtagsSettingsWidget()
{
}




void DebtagsSettingsWidget::on__pAddButton_clicked()
{
	Q3ListViewItemIterator it(_pShownFacetsList, Q3ListViewItemIterator::Selected);
	while ( it.current() ) 
	{
		Q3ListViewItem* pItem = (*it); // make a temporary copy of the item
		new Q3ListViewItem(_pHiddenFacetsList, pItem->text(0), pItem->text(1) );
		++it;
		emit facetHidden( toString(pItem->text(0)) );
		delete pItem;
	}
}

void DebtagsSettingsWidget::on__pRemoveButton_clicked()
{
	Q3ListViewItemIterator it(_pHiddenFacetsList, Q3ListViewItemIterator::Selected);
	while ( it.current() ) 
	{
		Q3ListViewItem* pItem = (*it); // make a temporary copy of the item
		new Q3ListViewItem(_pShownFacetsList, pItem->text(0), pItem->text(1) );
		++it;
		emit facetShown( toString(pItem->text(0)) );
		delete pItem;
	}
}

/** @brief This returns all facets that where selected to be hidden. */
set<string> DebtagsSettingsWidget::hiddenFacets()
{
	set<string> result;
	Q3ListViewItemIterator it(_pHiddenFacetsList);
	while ( it.current() ) 
	{
		result.insert( toString((*it)->text(0)) );
		++it;
	}
 return result;
}

/** @brief This returns all facets that where selected to be shown. */
set<string> DebtagsSettingsWidget::shownFacets()
{
	set<string> result;
	Q3ListViewItemIterator it(_pShownFacetsList);
	while ( it.current() ) 
	{
		result.insert( toString((*it)->text(0)) );
		++it;
	}
	return result;
}

==> packagesearch_2.2.6.tar.gz: packagesearch-2.2.6/src/plugins/debtagsplugin/debtagssettingswidget.cpp <==
//
// C++ Implementation: debtagssettingswidget
//
// Description: 
//
//
// Author: Benjamin Mesing <bensmail@gmx.net>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "debtagssettingswidget.h"

#include "aggregator.h"
#include <wibble/operators.h>

#include <helpers.h>

#include "exception.h"
#include "eptinstance.h"

#if 0
using namespace aptFront::cache::component;
using namespace aptFront::cache::entity;
#endif

DebtagsSettingsWidget::DebtagsSettingsWidget(const set<string>& hiddenFacets, 
	QWidget *parent, const char *name)
 : QWidget(parent), Ui::DebtagsSettingsWidget()
{
	using namespace wibble::operators;
	typedef ept::debtags::Vocabulary Vocabulary;
	typedef ept::debtags::Facet Facet;

	if (name)
		setObjectName(name);
	setupUi(this);

	Vocabulary& tags = EptInstance::aggregator()->vocabulary();

	std::set<Facet> hidden;
	for (set<string>::const_iterator it = hiddenFacets.begin(); it != hiddenFacets.end(); it++)
	{
		Facet f = tags.facetByName(*it);
		if (f.valid())
			hidden |= f;
	}
	std::set<Facet> facets = tags.facets();

	// iterate over all facets
	for ( std::set<Facet>::const_iterator it = facets.begin(); it != facets.end(); ++it )
	{
		const Facet& facet = *it;
		if ( hidden.find(facet) == hidden.end() ) // if the facet is not hidden
		// worked around gcc 4.1 not compiling this for an unknown reason
		// 		if ( !hidden.contains(facet) ) // if the facet is not hidden
		{
			new Q3ListViewItem(_pShownFacetsList, toQString(facet.name()), toQString(facet.shortDescription()));
		}
		else
		{
			new Q3ListViewItem(_pHiddenFacetsList, toQString(facet.name()), toQString(facet.shortDescription()));
		}
	}


}


DebtagsSettingsWidget::~DebtagsSettingsWidget()
{
}




void DebtagsSettingsWidget::on__pAddButton_clicked()
{
	Q3ListViewItemIterator it(_pShownFacetsList, Q3ListViewItemIterator::Selected);
	while ( it.current() ) 
	{
		Q3ListViewItem* pItem = (*it); // make a temporary copy of the item
		new Q3ListViewItem(_pHiddenFacetsList, pItem->text(0), pItem->text(1) );
		++it;
		emit facetHidden( toString(pItem->text(0)) );
		delete pItem;
	}
}

void DebtagsSettingsWidget::on__pRemoveButton_clicked()
{
	Q3ListViewItemIterator it(_pHiddenFacetsList, Q3ListViewItemIterator::Selected);
	while ( it.current() ) 
	{
		Q3ListViewItem* pItem = (*it); // make a temporary copy of the item
		new Q3ListViewItem(_pShownFacetsList, pItem->text(0), pItem->text(1) );
		++it;
		emit facetShown( toString(pItem->text(0)) );
		delete pItem;
	}
}

/** @brief This returns all facets that where selected to be hidden. */
set<string> DebtagsSettingsWidget::hiddenFacets()
{
	set<string> result;
	Q3ListViewItemIterator it(_pHiddenFacetsList);
	while ( it.current() ) 
	{
		result.insert( toString((*it)->text(0)) );
		++it;
	}
 return result;
}

/** @brief This returns all facets that where selected to be shown. */
set<string> DebtagsSettingsWidget::shownFacets()
{
	set<string> result;
	Q3ListViewItemIterator it(_pShownFacetsList);
	while ( it.current() ) 
	{
		result.insert( toString((*it)->text(0)) );
		++it;
	}
	return result;
}
